@@ -112,15 +112,6 @@ class GoogleCloudStorage(CompressStorageMixin, Storage):
         """
         return None
 
-    def path(self, *args, **kwargs):
-        """Get the local path of the file
-
-        This value is ALWAYS None because the path is not necessarily distinct for an object
-        not on the local filesystem.
-
-        This method is here for API compatibility with django's Storage class.
-        """
-
     @property
     def client(self):
         """The google-storage client for this store"""
@@ -135,6 +126,15 @@ class GoogleCloudStorage(CompressStorageMixin, Storage):
             self._bucket = self.client.bucket(self.settings.bucket_name)
         return self._bucket
 
+    @property
+    def bucket_name(self):
+        """The name of the bucket corresponding to this store
+
+        A convenience property referring to self.settings.bucket_name but here for backward compatibility
+        with django_storages and ease of general use
+        """
+        return self.settings.bucket_name
+
     def _normalize_name(self, name):
         """
         Normalizes the name so that paths like /path/to/ignored/../something.txt
